@@ -16,6 +16,11 @@
 
 `grid.isLocked` <-
 		function(varName){
+	if(is.null(.grid$schedulerMode))
+	{
+		cat("please run grid.init(...) first\n")
+		return(FALSE)
+	}
 	if(varName %in% .grid$lock$varName)
 		return(TRUE)
 	else
